{{- define "common-profile-spec" }}
volumeGroups:
  - name: lvm_root
    devices:
      - partition: lvm_root_part
  - name: lvm_lvp
    devices:
      - partition: lvm_lvp_part
logicalVolumes:
  - name: root
    vg: lvm_root
    # Means, all left space
    sizeGiB: 0
  - name: lvp
    vg: lvm_lvp
    # Means, all left space
    sizeGiB: 0
fileSystems:
  - fileSystem: vfat
    partition: config-2
  - fileSystem: vfat
    partition: uefi
    mountPoint: /boot/efi
  - fileSystem: ext4
    logicalVolume: root
    mountPoint: /
  - fileSystem: ext4
    logicalVolume: lvp
    mountPoint: /mnt/local-volumes/
preDeployScript: |
  #!/bin/bash -ex
  echo $(date) 'pre_deploy_script done' >> /root/pre_deploy_done
postDeployScript: |
  #!/bin/bash -ex
  echo $(date) 'post_deploy_script done' >> /root/post_deploy_done
grubConfig:
  defaultGrubOptions:
    - 'GRUB_DISABLE_RECOVERY="true"'
    - 'GRUB_PRELOAD_MODULES=lvm'
    - 'GRUB_TIMEOUT=20'
    - 'GRUB_CMDLINE_LINUX="console=tty0 console=ttyS1,115200n8 biosdevname=0 net.ifnames=1"'
    - 'GRUB_SERIAL_COMMAND="serial --unit=0 --speed=115200 --word=8 --parity=no --stop=1"'
kernelParameters:
  sysctl:
    # reboot machine after kernel panic. 15m*60
    kernel.panic: "900"
    # restrict kernel logs to root only
    kernel.dmesg_restrict: "1"
    # controls whether core dumps will append the PID to the core filename
    # useful for debugging multi-threaded applications
    kernel.core_uses_pid: "1"
    # increase system file descriptor limit
    # this value can be up to:
    #   - 9223372036854775807 (0x7fffffffffffffff) on a 64-bit system
    # be aware that the Linux kernel documentation suggests that inode-max should be 3-4 times
    #   larger than this value
    fs.file-max: "9223372036854775807"
    # The Linux kernel provides the Asynchronous non-blocking I/O (AIO) feature that allows a
    # process to initiate multiple I/O operations simultaneously without having to wait for any of them to complete.
    # This helps boost performance for applications that are able to overlap processing and I/O.
    fs.aio-max-nr: "1048576"
    # The inotify API provides a mechanism for monitoring file system events.
    # Inotify can be used to monitor individual files, or to monitor directories.
    # When a directory is monitored, inotify will return events for the directory itself, and for files inside the directory.
    fs.inotify.max_user_instances: "4096"
    #This file contains the maximum number of memory map areas a process may have.
    # Memory map areas are used as a side-effect of calling malloc, directly by mmap and mprotect, and also when loading shared libraries.
    # While most applications need less than a thousand maps, certain programs,
    # particularly malloc debuggers, may consume lots of them, e.g., up to one or two maps per allocation.
    vm.max_map_count: "262144"
{{- end }}
